@@ -1,16 +1,18 @@
-"""Handles differences between different distributions
-
-Authors: Dave Malcolm <dmalcolm@redhat.com>, Zack Cerza <zcerza@redhat.com>"""
-__author__ = "Dave Malcolm <dmalcolm@redhat.com>, Zack Cerza <zcerza@redhat.com>"
-
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import re
-from version import Version
-from logging import debugLogger as logger
+from dogtail.version import Version
+from dogtail.logging import debugLogger as logger
+from subprocess import check_output
+
+"""
+Handles differences between different distributions
+"""
+__author__ = "Dave Malcolm <dmalcolm@redhat.com>, Zack Cerza <zcerza@redhat.com>"
 
 
 class DistributionNotSupportedError(Exception):  # pragma: no cover
-
     """
     This distribution is not supported.
     """
@@ -24,7 +26,6 @@ class DistributionNotSupportedError(Exception):  # pragma: no cover
 
 
 class PackageNotFoundError(Exception):
-
     """
     Error finding the requested package.
     """
@@ -35,7 +36,6 @@ global distro
 
 
 class PackageDb(object):
-
     """
     Class to abstract the details of whatever software package database is in
     use (RPM, APT, etc)
@@ -48,7 +48,7 @@ class PackageDb(object):
     def getVersion(self, packageName):
         """
         Method to get the version of an installed package as a Version
-         instance (or raise an exception if not found)
+        instance (or raise an exception if not found)
 
         Note: does not know about distributions' internal revision numbers.
         """
@@ -57,7 +57,7 @@ class PackageDb(object):
     def getFiles(self, packageName):
         """
         Method to get a list of filenames owned by the package, or raise an
-         exception if not found.
+        exception if not found.
         """
         raise NotImplementedError
 
@@ -77,9 +77,9 @@ class PackageDb(object):
         for localePrefix in self.localePrefixes:
             if locale:
                 localePrefix = localePrefix + '/' + locale
-            os.path.walk(localePrefix, appendIfMoFile, moFiles)
+            os.walk(localePrefix, appendIfMoFile, moFiles)
 
-        return moFiles.keys()
+        return list(moFiles.keys())
 
     def getDependencies(self, packageName):
         """
@@ -91,7 +91,6 @@ class PackageDb(object):
 
 
 class _RpmPackageDb(PackageDb):  # pragma: no cover
-
     def __init__(self):
         PackageDb.__init__(self)
 
@@ -129,12 +128,11 @@ class _RpmPackageDb(PackageDb):  # pragma: no cover
                     if depName != packageName:
                         # Add to the Hash with a dummy value
                         result[depName] = None
-            return result.keys()
+            return list(result.keys())
         raise PackageNotFoundError(packageName)
 
 
 class _AptPackageDb(PackageDb):
-
     def __init__(self):
         PackageDb.__init__(self)
         self.cache = None
@@ -143,12 +141,11 @@ class _AptPackageDb(PackageDb):
         if not self.cache:
             import apt_pkg
             apt_pkg.init()
-            self.cache = apt_pkg.GetCache()
-        packages = self.cache.Packages
+            self.cache = apt_pkg.Cache()
+        packages = self.cache.packages
         for package in packages:
-            if package.Name == packageName:
-                verString = re.match(
-                    '.*Ver:\'(.*)-.*\' Section:', str(package.CurrentVer)).group(1)
+            if package.name == packageName:
+                verString = re.match('.*Ver:\'(.*)-.*\' Section:', str(package.current_ver)).group(1)
                 return Version.fromString(verString)
         raise PackageNotFoundError(packageName)
 
@@ -171,31 +168,29 @@ class _AptPackageDb(PackageDb):
         if not self.cache:
             import apt_pkg
             apt_pkg.init()
-            self.cache = apt_pkg.GetCache()
-        packages = self.cache.Packages
+            self.cache = apt_pkg.Cache()
+        packages = self.cache.packages
         for package in packages:
-            if package.Name == packageName:
-                current = package.CurrentVer
+            if package.name == packageName:
+                current = package.current_ver
                 if not current:
                     raise PackageNotFoundError(packageName)
-                depends = current.DependsList
+                depends = current.depends_list
                 list = depends['Depends']
                 for dependency in list:
-                    name = dependency[0].TargetPkg.Name
+                    name = dependency[0].target_pkg.name
                     # Add to the hash using a dummy value
                     result[name] = None
-        return result.keys()
+        return list(result.keys())
 
 
 class _UbuntuAptPackageDb(_AptPackageDb):
-
     def __init__(self):
         _AptPackageDb.__init__(self)
         self.localePrefixes.append(self.prefix + '/share/locale-langpack')
 
 
 class _PortagePackageDb(PackageDb):  # pragma: no cover
-
     def __init__(self):
         PackageDb.__init__(self)
 
@@ -208,17 +203,15 @@ class _PortagePackageDb(PackageDb):  # pragma: no cover
         # FIXME: this takes the first package returned in the list, in the
         # case that there are slotted packages, and removes the leading
         # category such as 'sys-apps'
-        gentooPackageName = portage.db["/"][
-            "vartree"].dbapi.match(packageName)[0].split('/')[1]
+        gentooPackageName = portage.db["/"]["vartree"].dbapi.match(packageName)[0].split('/')[1]
         # this removes the distribution specific versioning returning only the
         # upstream version
         upstreamVersion = portage.pkgsplit(gentooPackageName)[1]
-        # print "Version of package is: " + upstreamVersion
+        # print("Version of package is: " + upstreamVersion)
         return Version.fromString(upstreamVersion)
 
 
 class _ConaryPackageDb(PackageDb):  # pragma: no cover
-
     def __init__(self):
         PackageDb.__init__(self)
 
@@ -236,13 +229,11 @@ class _ConaryPackageDb(PackageDb):  # pragma: no cover
 
 
 class _SolarisPackageDb(PackageDb):  # pragma: no cover
-
     def __init__(self):
         PackageDb.__init__(self)
 
 
 class JhBuildPackageDb(PackageDb):  # pragma: no cover
-
     def __init__(self):
         PackageDb.__init__(self)
         prefixes = []
@@ -258,27 +249,43 @@ class JhBuildPackageDb(PackageDb):  # pragma: no cover
         for line in lines:
             if line:
                 result[line.strip()] = None
-        return result.keys()
+        return list(result.keys())
+
+
+class _ContinuousPackageDb(PackageDb):
+
+    def __init__(self):
+        PackageDb.__init__(self)
+
+    def getVersion(self, packageName):
+        return ''
+
+    def getFiles(self, packageName):
+        return check_output(
+            ["ls -1 /usr/share/locale/*/LC_MESSAGES/%s.mo" % packageName], shell=True).strip().split('\n')
+
+    def getDependencies(self, packageName):
+        # Simulate a set using a hash (to a dummy value);
+        # sets were only added in Python 2.4
+        return []
 
 
 class Distro(object):
-
     """
     Class representing a distribution.
 
     Scripts may want to do arbitrary logic based on whichever distro is in use
     (e.g. handling differences in names of packages, distribution-specific
-     patches, etc.)
+    patches, etc.)
 
     We can either create methods in the Distro class to handle these, or we
-     can use constructs like isinstance(distro, Ubuntu) to handle this. We can
+    can use constructs like isinstance(distro, Ubuntu) to handle this. We can
     even create hierarchies of distro subclasses to handle this kind of thing
     (could get messy fast though)
     """
 
 
 class Fedora(Distro):  # pragma: no cover
-
     def __init__(self):
         self.packageDb = _RpmPackageDb()
 
@@ -288,47 +295,45 @@ class RHEL(Fedora):  # pragma: no cover
 
 
 class Debian(Distro):  # pragma: no cover
-
     def __init__(self):
         self.packageDb = _AptPackageDb()
 
 
 class Ubuntu(Debian):
-
     def __init__(self):
         self.packageDb = _UbuntuAptPackageDb()
 
 
 class Suse(Distro):  # pragma: no cover
-
     def __init__(self):
         self.packageDb = _RpmPackageDb()
 
 
 class Gentoo(Distro):  # pragma: no cover
-
     def __init__(self):
         self.packageDb = _PortagePackageDb()
 
 
 class Conary(Distro):  # pragma: no cover
-
     def __init__(self):
         self.packageDb = _ConaryPackageDb()
 
 
 class Solaris(Distro):  # pragma: no cover
-
     def __init__(self):
         self.packageDb = _SolarisPackageDb()
 
 
 class JHBuild(Distro):  # pragma: no cover
-
     def __init__(self):
         self.packageDb = JhBuildPackageDb()
 
 
+class GnomeContinuous(Distro):  # pragma: no cover
+    def __init__(self):
+        self.packageDb = _ContinuousPackageDb()
+
+
 def detectDistro():
     logger.log("Detecting distribution:", newline=False)
 
@@ -353,6 +358,9 @@ def detectDistro():
     elif os.path.exists("/etc/release") and \
             re.match(".*Solaris", open("/etc/release").readline()):  # pragma: no cover
         distro = Solaris()  # pragma: no cover
+    elif os.path.exists("/etc/os-release") and \
+            re.match(".*GNOME-Continuous", open("/etc/os-release").readline()):  # pragma: no cover
+        distro = GnomeContinuous()  # pragma: no cover
     else:
         raise DistributionNotSupportedError("Unknown")  # pragma: no cover
     logger.log(distro.__class__.__name__)
