@@ -1,9 +1,11 @@
-"""Utility functions for 'dumping' trees of Node objects.
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-Author: Zack Cerza <zcerza@redhat.com>"""
+"""
+Utility functions for 'dumping' trees of Node objects.
+"""
 __author__ = "Zack Cerza <zcerza@redhat.com>"
 
-from __builtin__ import file
 
 spacer = ' '
 
@@ -14,19 +16,23 @@ def plain(node, fileName=None):
     """
     def crawl(node, depth):
         dump(node, depth)
-        for action in node.actions.values():
+        for action in list(node.actions.values()):
             dump(action, depth + 1)
         for child in node.children:
             crawl(child, depth + 1)
 
     def dumpFile(item, depth):
-        _file.write(spacer * depth + str(item) + '\n')
+        _file.write(str(spacer * depth) + str(item) + str('\n'))
 
     def dumpStdOut(item, depth):
-        print(spacer * depth + str(item))
+        try:
+            print(spacer * depth + str(item))
+        except UnicodeDecodeError:
+            print(spacer * depth + str(item).decode('utf8'))
+
     if fileName:
         dump = dumpFile
-        _file = file(fileName, 'w')
+        _file = open(fileName, 'w')
     else:
         dump = dumpStdOut
 
