@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
-"""
-Author: David Malcolm <dmalcolm@redhat.com>
-"""
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 __author__ = """David Malcolm <dmalcolm@redhat.com>"""
 
 
 class SearchPath(object):
-
     """
     Class used by the recording framework (and for more verbose script
     logging) for identifying nodes in a persistent way, independent of the
@@ -26,38 +24,33 @@ class SearchPath(object):
     """
 
     def __init__(self):
-        self.__list = []
+        self.lst = []
 
     def __str__(self):
         result = "{"
-        for (predicate, isRecursive) in self.__list:
-            result += "/(%s,%s)" % (
-                predicate.describeSearchResult(), isRecursive)
+        for (predicate, isRecursive) in self.lst:
+            result += "/(%s,%s)" % (predicate.describeSearchResult(), isRecursive)
         return result + "}"
 
     # We need equality to work so that dicts of these work:
     def __eq__(self, other):
-        # print "eq: self:%s"%self
-        # print "       other:%s"%other
-        if len(self.__list) != len(other.__list):
-            # print "nonequal length"
+        if len(self.lst) != len(other.lst):
             return False
         else:
-            for i in range(len(self.__list)):
-                if self.__list[i] != other.__list[i]:
+            for i in range(len(self.lst)):
+                if self.lst[i] != other.lst[i]:
                     return False
-        # print True
         return True
 
     def append(self, predicate, isRecursive):
         assert predicate
-        self.__list.append((predicate, isRecursive))
+        self.lst.append((predicate, isRecursive))
 
     def __iter__(self):
-        return iter(self.__list)
+        return iter(self.lst)
 
     def length(self):
-        return len(self.__list)
+        return len(self.lst)
 
     def makeScriptMethodCall(self):
         """
@@ -66,7 +59,7 @@ class SearchPath(object):
         Generate the Python source code that will carry out this search.
         """
         result = ""
-        for (predicate, isRecursive) in self.__list:
+        for (predicate, isRecursive) in self.lst:
             # print predicate
             # print self.generateVariableName(predicate)
             result += "." + predicate.makeScriptMethodCall(isRecursive)
@@ -79,13 +72,14 @@ class SearchPath(object):
         to this one (a copy of the second part of the list).    Otherwise
         return None.
         """
-        for i in range(len(self.__list)):
-            if self.__list[i] != other.__list[i]:
+        i = 0
+        for i in range(len(self.lst)):
+            if self.lst[i] != other.lst[i]:
                 break
         if i > 0:
             # Slice from this point to the end:
             result = SearchPath()
-            result.__list = other.__list[i + 1:]
+            result.lst = other.lst[i + 1:]
 
             if False:
                 print("....................")
@@ -105,9 +99,9 @@ class SearchPath(object):
         """
         result = SearchPath()
         for i in range(n):
-            result.__list.append(self.__list[i])
+            result.lst.append(self.lst[i])
         return result
 
     def getPredicate(self, i):
-        (predicate, isRecursive) = self.__list[i]
+        (predicate, _) = self.lst[i]
         return predicate
